@@ -6,29 +6,9 @@
 
 #include "bjb-controller.h"
 
-#define BJB_TYPE_WINDOW_BASE                  (bjb_window_base_get_type ())
-#define BJB_WINDOW_BASE(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), BJB_TYPE_WINDOW_BASE, BjbWindowBase))
-#define BJB_IS_WINDOW_BASE(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BJB_TYPE_WINDOW_BASE))
-#define BJB_WINDOW_BASE_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), BJB_TYPE_WINDOW_BASE, BjbWindowBaseClass))
-#define BJB_IS_WINDOW_BASE_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), BJB_TYPE_WINDOW_BASE))
-#define BJB_WINDOW_BASE_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), BJB_TYPE_WINDOW_BASE, BjbWindowBaseClass))
+#define BJB_TYPE_WINDOW_BASE (bjb_window_base_get_type ())
 
-typedef struct _BjbWindowBase        BjbWindowBase;
-typedef struct _BjbWindowBaseClass   BjbWindowBaseClass;
-
-typedef struct _BjbWindowBasePriv BjbWindowBasePriv;
-
-struct _BjbWindowBaseClass
-{
-  GtkApplicationWindowClass parent_class;
-};
-
-
-struct _BjbWindowBase
-{
-  GtkApplicationWindow parent_instance ;
-  BjbWindowBasePriv *priv;
-};
+G_DECLARE_FINAL_TYPE (BjbWindowBase, bjb_window_base, BJB, WINDOW_BASE, GtkApplicationWindow)
 
 typedef enum {
   BJB_WINDOW_BASE_MAIN_VIEW,
@@ -42,10 +22,6 @@ typedef enum {
 } BjbWindowViewType;
 
 
-
-GType                  bjb_window_base_get_type           (void);
-
-
 GtkWindow             *bjb_window_base_new                (BijiNoteObj *note);
 
 
@@ -79,16 +55,12 @@ BijiNoteObj           *bjb_window_base_get_note (BjbWindowBase *self);
 gboolean               switch_window_fullscreen (void);
 
 
+GtkWidget             *bjb_window_base_get_search_bar (BjbWindowBase *self);
+
+
 gboolean               bjb_window_base_get_show_search_bar (BjbWindowBase *self);
 
 
-gboolean               bjb_window_base_set_show_search_bar (BjbWindowBase *self, gboolean show);
-
-
-gboolean               bjb_window_base_toggle_search_button (BjbWindowBase *self,
-                                               gboolean active);
-
-
 void                   bjb_window_base_set_active (BjbWindowBase *self, gboolean active);
 
 
